import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleLinear,
  scaleTime,
  scaleOrdinal,
  scaleSqrt,
  max,
  timeFormat,
  extent
} from 'd3';
import { getRingChartConfig } from './plotConfig';
import { useData } from './useData';
import { Marks } from './Marks';
import { ColorLegend } from './ColorLegend';

const plotConfig = getRingChartConfig();

const width = +plotConfig.width;
const height = +plotConfig.height;
const margin = plotConfig.margin;
const fadeOpacity = +plotConfig.fadeOpacity;
const innerHeight = +plotConfig.innerHeight;
const innerWidth = +plotConfig.innerWidth;
const innerRadius = +plotConfig.innerRadius;
const outerRadius = +plotConfig.outerRadius;
const centerX = +plotConfig.centerX;
const centerY = +plotConfig.centerY;

const App = () => {
  let data = useData();

  const [hoveredValue, setHoveredValue] = useState(null);

  if (!data) {
    return <pre>Loading...</pre>;
  }
  data = data.filter(d => d.year == 2016);
  console.log(data[0]);
  const fullCircle = 2 * Math.PI;
  const xValue = d => d.dateFormatted;
  const xAxisLabel = 'Date';
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, fullCircle])
    .nice();
  console.log(xScale(new Date('12/1')));

  const yValue = d => d.WEATHER_DELAY;
  const yAxisLabel = 'Weather_delay';
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerRadius, outerRadius]);

  const colorLegendValue = d => d.weatherLevel;
  const colorLegendLabel = 'Bad weather';

  const colorArcValue = d => d.WEATHER_DELAY;

  const filteredData = data.filter(d => hoveredValue === colorLegendValue(d));

  const colorLegendScale = scaleOrdinal()
    .domain(data.map(colorLegendValue))
    .range(['#4099ff', '#e67e22', '#8E6C8A']);

  const colorArcScale = (value, year) => {
    if (value === 0) {
      return colorLegendScale(year);
    } else {
      return '#ff0000';
    }
  };

  return (
    <svg width={width} height={height}>
      <g className="title" transform={`translate(${width / 2},${40})`}>
        <text>Ring chart</text>
      </g>
      svg .append('text') .text(text) .attr('transform', 'translate(' +
      svg.attr('width') / 2 + ',40)') .attr('font-size', '3em');
      <g transform={`translate(${margin.left},${margin.top})`}>
        <g transform={`translate(${innerWidth + 60}, 60)`}>
          <text x={35} y={-25} className="axis-label" textAnchor="middle">
            {colorLegendLabel}
          </text>
          <ColorLegend
            tickSpacing={22}
            tickSize={10}
            tickTextOffset={12}
            tickSize={5}
            colorScale={colorLegendScale}
            onHover={setHoveredValue}
            hoveredValue={hoveredValue}
            fadeOpacity={fadeOpacity}
          />
        </g>
        <g transform={`translate(${innerWidth / 1.6},${innerHeight / 2})`}>
          <g opacity={hoveredValue ? fadeOpacity : 0.5}>
            <Marks
              data={data}
              xScale={xScale}
              xValue={xValue}
              yScale={yScale}
              yValue={yValue}
              colorScale={colorArcScale}
              colorValue={colorLegendValue}
              innerRadius={innerRadius}
            />
          </g>
          <g opacity={0.5}>
            <Marks
              data={data}
              xScale={xScale}
              xValue={xValue}
              yScale={yScale}
              yValue={yValue}
              colorScale={colorArcScale}
              colorValue={colorLegendValue}
              innerRadius={innerRadius}
            />
          </g>
        </g>
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
